@@ -5,31 +5,31 @@ var mimeTypes = require('..')
 describe('mimeTypes', function () {
   describe('.charset(type)', function () {
     it('should return "UTF-8" for "application/json"', function () {
-      assert.equal(mimeTypes.charset('application/json'), 'UTF-8')
+      assert.strictEqual(mimeTypes.charset('application/json'), 'UTF-8')
     })
 
     it('should return "UTF-8" for "application/json; foo=bar"', function () {
-      assert.equal(mimeTypes.charset('application/json; foo=bar'), 'UTF-8')
+      assert.strictEqual(mimeTypes.charset('application/json; foo=bar'), 'UTF-8')
     })
 
     it('should return "UTF-8" for "application/javascript"', function () {
-      assert.equal(mimeTypes.charset('application/javascript'), 'UTF-8')
+      assert.strictEqual(mimeTypes.charset('application/javascript'), 'UTF-8')
     })
 
     it('should return "UTF-8" for "application/JavaScript"', function () {
-      assert.equal(mimeTypes.charset('application/JavaScript'), 'UTF-8')
+      assert.strictEqual(mimeTypes.charset('application/JavaScript'), 'UTF-8')
     })
 
     it('should return "UTF-8" for "text/html"', function () {
-      assert.equal(mimeTypes.charset('text/html'), 'UTF-8')
+      assert.strictEqual(mimeTypes.charset('text/html'), 'UTF-8')
     })
 
     it('should return "UTF-8" for "TEXT/HTML"', function () {
-      assert.equal(mimeTypes.charset('TEXT/HTML'), 'UTF-8')
+      assert.strictEqual(mimeTypes.charset('TEXT/HTML'), 'UTF-8')
     })
 
     it('should return "UTF-8" for any text/*', function () {
-      assert.equal(mimeTypes.charset('text/x-bogus'), 'UTF-8')
+      assert.strictEqual(mimeTypes.charset('text/x-bogus'), 'UTF-8')
     })
 
     it('should return false for unknown types', function () {
@@ -50,19 +50,19 @@ describe('mimeTypes', function () {
 
   describe('.contentType(extension)', function () {
     it('should return content-type for "html"', function () {
-      assert.equal(mimeTypes.contentType('html'), 'text/html; charset=utf-8')
+      assert.strictEqual(mimeTypes.contentType('html'), 'text/html; charset=utf-8')
     })
 
     it('should return content-type for ".html"', function () {
-      assert.equal(mimeTypes.contentType('.html'), 'text/html; charset=utf-8')
+      assert.strictEqual(mimeTypes.contentType('.html'), 'text/html; charset=utf-8')
     })
 
     it('should return content-type for "jade"', function () {
-      assert.equal(mimeTypes.contentType('jade'), 'text/jade; charset=utf-8')
+      assert.strictEqual(mimeTypes.contentType('jade'), 'text/jade; charset=utf-8')
     })
 
     it('should return content-type for "json"', function () {
-      assert.equal(mimeTypes.contentType('json'), 'application/json; charset=utf-8')
+      assert.strictEqual(mimeTypes.contentType('json'), 'application/json; charset=utf-8')
     })
 
     it('should return false for unknown extensions', function () {
@@ -79,35 +79,35 @@ describe('mimeTypes', function () {
 
   describe('.contentType(type)', function () {
     it('should attach charset to "application/json"', function () {
-      assert.equal(mimeTypes.contentType('application/json'), 'application/json; charset=utf-8')
+      assert.strictEqual(mimeTypes.contentType('application/json'), 'application/json; charset=utf-8')
     })
 
     it('should attach charset to "application/json; foo=bar"', function () {
-      assert.equal(mimeTypes.contentType('application/json; foo=bar'), 'application/json; foo=bar; charset=utf-8')
+      assert.strictEqual(mimeTypes.contentType('application/json; foo=bar'), 'application/json; foo=bar; charset=utf-8')
     })
 
     it('should attach charset to "TEXT/HTML"', function () {
-      assert.equal(mimeTypes.contentType('TEXT/HTML'), 'TEXT/HTML; charset=utf-8')
+      assert.strictEqual(mimeTypes.contentType('TEXT/HTML'), 'TEXT/HTML; charset=utf-8')
     })
 
     it('should attach charset to "text/html"', function () {
-      assert.equal(mimeTypes.contentType('text/html'), 'text/html; charset=utf-8')
+      assert.strictEqual(mimeTypes.contentType('text/html'), 'text/html; charset=utf-8')
     })
 
     it('should not alter "text/html; charset=iso-8859-1"', function () {
-      assert.equal(mimeTypes.contentType('text/html; charset=iso-8859-1'), 'text/html; charset=iso-8859-1')
+      assert.strictEqual(mimeTypes.contentType('text/html; charset=iso-8859-1'), 'text/html; charset=iso-8859-1')
     })
 
     it('should return type for unknown types', function () {
-      assert.equal(mimeTypes.contentType('application/x-bogus'), 'application/x-bogus')
+      assert.strictEqual(mimeTypes.contentType('application/x-bogus'), 'application/x-bogus')
     })
   })
 
   describe('.extension(type)', function () {
     it('should return extension for mime type', function () {
-      assert.equal(mimeTypes.extension('text/html'), 'html')
-      assert.equal(mimeTypes.extension(' text/html'), 'html')
-      assert.equal(mimeTypes.extension('text/html '), 'html')
+      assert.strictEqual(mimeTypes.extension('text/html'), 'html')
+      assert.strictEqual(mimeTypes.extension(' text/html'), 'html')
+      assert.strictEqual(mimeTypes.extension('text/html '), 'html')
     })
 
     it('should return false for unknown type', function () {
@@ -126,47 +126,47 @@ describe('mimeTypes', function () {
     })
 
     it('should return extension for mime type with parameters', function () {
-      assert.equal(mimeTypes.extension('text/html;charset=UTF-8'), 'html')
-      assert.equal(mimeTypes.extension('text/HTML; charset=UTF-8'), 'html')
-      assert.equal(mimeTypes.extension('text/html; charset=UTF-8'), 'html')
-      assert.equal(mimeTypes.extension('text/html; charset=UTF-8 '), 'html')
-      assert.equal(mimeTypes.extension('text/html ; charset=UTF-8'), 'html')
+      assert.strictEqual(mimeTypes.extension('text/html;charset=UTF-8'), 'html')
+      assert.strictEqual(mimeTypes.extension('text/HTML; charset=UTF-8'), 'html')
+      assert.strictEqual(mimeTypes.extension('text/html; charset=UTF-8'), 'html')
+      assert.strictEqual(mimeTypes.extension('text/html; charset=UTF-8 '), 'html')
+      assert.strictEqual(mimeTypes.extension('text/html ; charset=UTF-8'), 'html')
     })
   })
 
   describe('.lookup(extension)', function () {
     it('should return mime type for ".html"', function () {
-      assert.equal(mimeTypes.lookup('.html'), 'text/html')
+      assert.strictEqual(mimeTypes.lookup('.html'), 'text/html')
     })
 
     it('should return mime type for ".js"', function () {
-      assert.equal(mimeTypes.lookup('.js'), 'application/javascript')
+      assert.strictEqual(mimeTypes.lookup('.js'), 'application/javascript')
     })
 
     it('should return mime type for ".json"', function () {
-      assert.equal(mimeTypes.lookup('.json'), 'application/json')
+      assert.strictEqual(mimeTypes.lookup('.json'), 'application/json')
     })
 
     it('should return mime type for ".rtf"', function () {
-      assert.equal(mimeTypes.lookup('.rtf'), 'application/rtf')
+      assert.strictEqual(mimeTypes.lookup('.rtf'), 'application/rtf')
     })
 
     it('should return mime type for ".txt"', function () {
-      assert.equal(mimeTypes.lookup('.txt'), 'text/plain')
+      assert.strictEqual(mimeTypes.lookup('.txt'), 'text/plain')
     })
 
     it('should return mime type for ".xml"', function () {
-      assert.equal(mimeTypes.lookup('.xml'), 'application/xml')
+      assert.strictEqual(mimeTypes.lookup('.xml'), 'application/xml')
     })
 
     it('should work without the leading dot', function () {
-      assert.equal(mimeTypes.lookup('html'), 'text/html')
-      assert.equal(mimeTypes.lookup('xml'), 'application/xml')
+      assert.strictEqual(mimeTypes.lookup('html'), 'text/html')
+      assert.strictEqual(mimeTypes.lookup('xml'), 'application/xml')
     })
 
     it('should be case insensitive', function () {
-      assert.equal(mimeTypes.lookup('HTML'), 'text/html')
-      assert.equal(mimeTypes.lookup('.Xml'), 'application/xml')
+      assert.strictEqual(mimeTypes.lookup('HTML'), 'text/html')
+      assert.strictEqual(mimeTypes.lookup('.Xml'), 'application/xml')
     })
 
     it('should return false for unknown extension', function () {
@@ -184,22 +184,22 @@ describe('mimeTypes', function () {
 
   describe('.lookup(path)', function () {
     it('should return mime type for file name', function () {
-      assert.equal(mimeTypes.lookup('page.html'), 'text/html')
+      assert.strictEqual(mimeTypes.lookup('page.html'), 'text/html')
     })
 
     it('should return mime type for relative path', function () {
-      assert.equal(mimeTypes.lookup('path/to/page.html'), 'text/html')
-      assert.equal(mimeTypes.lookup('path\\to\\page.html'), 'text/html')
+      assert.strictEqual(mimeTypes.lookup('path/to/page.html'), 'text/html')
+      assert.strictEqual(mimeTypes.lookup('path\\to\\page.html'), 'text/html')
     })
 
     it('should return mime type for absolute path', function () {
-      assert.equal(mimeTypes.lookup('/path/to/page.html'), 'text/html')
-      assert.equal(mimeTypes.lookup('C:\\path\\to\\page.html'), 'text/html')
+      assert.strictEqual(mimeTypes.lookup('/path/to/page.html'), 'text/html')
+      assert.strictEqual(mimeTypes.lookup('C:\\path\\to\\page.html'), 'text/html')
     })
 
     it('should be case insensitive', function () {
-      assert.equal(mimeTypes.lookup('/path/to/PAGE.HTML'), 'text/html')
-      assert.equal(mimeTypes.lookup('C:\\path\\to\\PAGE.HTML'), 'text/html')
+      assert.strictEqual(mimeTypes.lookup('/path/to/PAGE.HTML'), 'text/html')
+      assert.strictEqual(mimeTypes.lookup('C:\\path\\to\\PAGE.HTML'), 'text/html')
     })
 
     it('should return false for unknown extension', function () {
